"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setSession = exports.readSystemInfo = exports.createSession = exports.configureCSpace = void 0;
var _cspaceClient = _interopRequireDefault(require("cspace-client"));
var _get = _interopRequireDefault(require("lodash/get"));
var _modalNames = require("../constants/modalNames");
var _session = _interopRequireWildcard(require("../helpers/session"));
var _notification = require("./notification");
var _actionCodes = require("../constants/actionCodes");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
let client;
const createSession = (authCode, codeVerifier, redirectUri) => {
  if (typeof authCode === 'undefined') {
    return client.session();
  }
  return client.session({
    authCode,
    codeVerifier,
    redirectUri
  });
};
exports.createSession = createSession;
const setSession = newSession => {
  (0, _session.storeSession)(newSession);
  return {
    type: _actionCodes.CSPACE_CONFIGURED,
    payload: (0, _session.default)().config(),
    meta: {
      username: (0, _session.default)().username()
    }
  };
};
exports.setSession = setSession;
const readSystemInfo = config => dispatch => (0, _session.default)().read('systeminfo', {
  auth: false,
  params: {
    tid: (0, _get.default)(config, 'tenantId')
  }
}).then(response => dispatch({
  type: _actionCodes.SYSTEM_INFO_READ_FULFILLED,
  payload: response
})).catch(error => dispatch({
  type: _actionCodes.SYSTEM_INFO_READ_REJECTED,
  payload: error
}));
exports.readSystemInfo = readSystemInfo;
const configureCSpace = config => dispatch => {
  client = (0, _cspaceClient.default)({
    url: (0, _get.default)(config, 'serverUrl'),
    onError: error => {
      const status = (0, _get.default)(error, ['response', 'status']);
      if (status === 401) {
        const headers = (0, _get.default)(error, ['response', 'headers']);
        const wwwAuthenticate = headers.get('Www-Authenticate');
        if (wwwAuthenticate && wwwAuthenticate.includes('invalid_token')) {
          // The stored token is no longer valid. Show the login modal.

          dispatch((0, _notification.openModal)(_modalNames.MODAL_LOGIN));
        }
      }
      return Promise.reject(error);
    }
  });
  const newSession = createSession();
  dispatch(setSession(newSession));
  return Promise.resolve();
};
exports.configureCSpace = configureCSpace;