"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _immutable = _interopRequireDefault(require("immutable"));
var _get = _interopRequireDefault(require("lodash/get"));
var _RecordFormContainer = _interopRequireDefault(require("../../containers/record/RecordFormContainer"));
var _SubrecordDetachButton = _interopRequireDefault(require("./SubrecordDetachButton"));
var _permissionHelpers = require("../../helpers/permissionHelpers");
var _recordDataHelpers = require("../../helpers/recordDataHelpers");
var _SubrecordEditor = _interopRequireDefault(require("../../../styles/cspace-ui/SubrecordEditor.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const propTypes = {
  config: _propTypes.default.shape({
    recordTypes: _propTypes.default.object
  }),
  subrecordConfig: _propTypes.default.shape({
    recordType: _propTypes.default.string,
    vocabulary: _propTypes.default.string,
    csidField: _propTypes.default.arrayOf(_propTypes.default.string)
  }),
  containerCsid: _propTypes.default.string,
  csid: _propTypes.default.string,
  data: _propTypes.default.instanceOf(_immutable.default.Map),
  formName: _propTypes.default.string,
  name: _propTypes.default.string,
  perms: _propTypes.default.instanceOf(_immutable.default.Map),
  showDetachButton: _propTypes.default.bool,
  detachSubrecord: _propTypes.default.func,
  readOnly: _propTypes.default.bool
};
class SubrecordEditor extends _react.Component {
  constructor() {
    super();
    this.handleDetachButtonClick = this.handleDetachButtonClick.bind(this);
  }
  handleDetachButtonClick() {
    const {
      config,
      containerCsid,
      name,
      subrecordConfig,
      detachSubrecord
    } = this.props;
    const subrecordTypeConfig = (0, _get.default)(config, ['recordTypes', subrecordConfig.recordType]);
    if (detachSubrecord) {
      detachSubrecord(config, containerCsid, subrecordConfig.csidField, name, subrecordTypeConfig);
    }
  }
  render() {
    const {
      config,
      csid,
      data,
      formName,
      perms,
      showDetachButton,
      subrecordConfig,
      readOnly
    } = this.props;
    const {
      recordType,
      vocabulary
    } = subrecordConfig;
    const recordTypeConfig = config.recordTypes[recordType];
    if (!recordTypeConfig) {
      return null;
    }
    if (!(0, _permissionHelpers.canRead)(recordType, perms)) {
      return null;
    }
    const subrecordReadOnly = readOnly || !(csid ? (0, _permissionHelpers.canUpdate)(recordType, perms) : (0, _permissionHelpers.canCreate)(recordType, perms)) || (0, _recordDataHelpers.isRecordImmutable)(data);
    const detachButton = showDetachButton && !readOnly && (0, _recordDataHelpers.isExistingRecord)(data) ? /*#__PURE__*/_react.default.createElement(_SubrecordDetachButton.default, {
      onClick: this.handleDetachButtonClick
    }) : null;
    return /*#__PURE__*/_react.default.createElement("div", {
      className: _SubrecordEditor.default.common
    }, /*#__PURE__*/_react.default.createElement("header", null, detachButton), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_RecordFormContainer.default, {
      config: config,
      recordType: recordType,
      recordTypeConfig: recordTypeConfig,
      vocabulary: vocabulary,
      csid: csid,
      data: data,
      formName: formName,
      readOnly: subrecordReadOnly
    })));
  }
}
exports.default = SubrecordEditor;
SubrecordEditor.propTypes = propTypes;